==> kdesvn_1.0.4.orig.tar.gz: kdesvn-1.0.4/src/svnfrontend/fronthelpers/rangeinput_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef RANGEINPUT_IMPL_H
#define RANGEINPUT_IMPL_H

#include "rangeinput.h"
#include "src/svnqt/revision.hpp"
#include <qpair.h>

class Rangeinput_impl: public RangeInputDlg {
Q_OBJECT
public:
    Rangeinput_impl(QWidget *parent = 0, const char *name = 0);
    virtual ~Rangeinput_impl();

    typedef QPair<svn::Revision,svn::Revision> revision_range;

    revision_range getRange();

    virtual void setStartOnly(bool theValue);
    virtual void setNoWorking(bool aValue);


    bool StartOnly() const;
    void setHeadDefault();

protected slots:
    virtual void onHelp();
    virtual void stopHeadToggled(bool);
    virtual void stopBaseToggled(bool);
    virtual void stopNumberToggled(bool);
    virtual void startHeadToggled(bool);
    virtual void startBaseToggled(bool);
    virtual void startNumberToggled(bool);
    virtual void stopDateToggled(bool);
    virtual void startDateToggled(bool);
protected:
    bool m_StartOnly;
};

#endif

==> kdesvn_1.4.1.orig.tar.gz: kdesvn-1.4.1/src/svnfrontend/fronthelpers/rangeinput_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef RANGEINPUT_IMPL_H
#define RANGEINPUT_IMPL_H

#include "ui_rangeinput.h"
#include "src/svnqt/revision.hpp"
#include <qpair.h>

class Rangeinput_impl: public QWidget, public Ui::RangeInput {
Q_OBJECT
public:
    Rangeinput_impl(QWidget *parent = 0, const char *name = 0);
    virtual ~Rangeinput_impl();

    typedef QPair<svn::Revision,svn::Revision> revision_range;

    revision_range getRange();

    virtual void setStartOnly(bool theValue);
    virtual void setNoWorking(bool aValue);


    bool StartOnly() const;
    void setHeadDefault();

protected slots:
    virtual void onHelp();
    virtual void stopHeadToggled(bool);
    virtual void stopBaseToggled(bool);
    virtual void stopNumberToggled(bool);
    virtual void startHeadToggled(bool);
    virtual void startBaseToggled(bool);
    virtual void startNumberToggled(bool);
    virtual void stopDateToggled(bool);
    virtual void startDateToggled(bool);
protected:
    bool m_StartOnly;
};

#endif
